"use strict";

var _utils = require("./utils");

var _graph = _interopRequireDefault(require("./graph"));

var _errors = require("./errors");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

/**
 * Alternative constructors.
 */
var DirectedGraph =
/*#__PURE__*/
function (_Graph) {
  _inheritsLoose(DirectedGraph, _Graph);

  function DirectedGraph(options) {
    return _Graph.call(this, (0, _utils.assign)({
      type: 'directed'
    }, options)) || this;
  }

  return DirectedGraph;
}(_graph["default"]);

var UndirectedGraph =
/*#__PURE__*/
function (_Graph2) {
  _inheritsLoose(UndirectedGraph, _Graph2);

  function UndirectedGraph(options) {
    return _Graph2.call(this, (0, _utils.assign)({
      type: 'undirected'
    }, options)) || this;
  }

  return UndirectedGraph;
}(_graph["default"]);

var MultiGraph =
/*#__PURE__*/
function (_Graph3) {
  _inheritsLoose(MultiGraph, _Graph3);

  function MultiGraph(options) {
    return _Graph3.call(this, (0, _utils.assign)({
      multi: true
    }, options)) || this;
  }

  return MultiGraph;
}(_graph["default"]);

var MultiDirectedGraph =
/*#__PURE__*/
function (_Graph4) {
  _inheritsLoose(MultiDirectedGraph, _Graph4);

  function MultiDirectedGraph(options) {
    return _Graph4.call(this, (0, _utils.assign)({
      multi: true,
      type: 'directed'
    }, options)) || this;
  }

  return MultiDirectedGraph;
}(_graph["default"]);

var MultiUndirectedGraph =
/*#__PURE__*/
function (_Graph5) {
  _inheritsLoose(MultiUndirectedGraph, _Graph5);

  function MultiUndirectedGraph(options) {
    return _Graph5.call(this, (0, _utils.assign)({
      multi: true,
      type: 'undirected'
    }, options)) || this;
  }

  return MultiUndirectedGraph;
}(_graph["default"]);
/**
 * Attaching static #.from method to each of the constructors.
 */


function attachStaticFromMethod(Class) {
  /**
   * Builds a graph from serialized data or another graph's data.
   *
   * @param  {Graph|SerializedGraph} data      - Hydratation data.
   * @param  {object}                [options] - Options.
   * @return {Class}
   */
  Class.from = function (data, options) {
    var instance = new Class(options);
    instance["import"](data);
    return instance;
  };
}

attachStaticFromMethod(_graph["default"]);
attachStaticFromMethod(DirectedGraph);
attachStaticFromMethod(UndirectedGraph);
attachStaticFromMethod(MultiGraph);
attachStaticFromMethod(MultiDirectedGraph);
attachStaticFromMethod(MultiUndirectedGraph);
/**
 * Attaching the various constructors to the Graph class itself so we can
 * keep CommonJS semantics so everyone can consume the library easily.
 */

_graph["default"].Graph = _graph["default"];
_graph["default"].DirectedGraph = DirectedGraph;
_graph["default"].UndirectedGraph = UndirectedGraph;
_graph["default"].MultiGraph = MultiGraph;
_graph["default"].MultiDirectedGraph = MultiDirectedGraph;
_graph["default"].MultiUndirectedGraph = MultiUndirectedGraph;
_graph["default"].InvalidArgumentsGraphError = _errors.InvalidArgumentsGraphError;
_graph["default"].NotFoundGraphError = _errors.NotFoundGraphError;
_graph["default"].UsageGraphError = _errors.UsageGraphError;
module.exports = _graph["default"];